"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _AssignmentModel = _interopRequireDefault(require("../model/AssignmentModel"));

var _HTTPValidationError = _interopRequireDefault(require("../model/HTTPValidationError"));

var _Message = _interopRequireDefault(require("../model/Message"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
* Assignments service.
* @module api/AssignmentsApi
* @version 0.1.0
*/
var AssignmentsApi = /*#__PURE__*/function () {
  /**
  * Constructs a new AssignmentsApi. 
  * @alias module:api/AssignmentsApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function AssignmentsApi(apiClient) {
    _classCallCheck(this, AssignmentsApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Callback function to receive the result of the createAssignment operation.
   * @callback module:api/AssignmentsApi~createAssignmentCallback
   * @param {String} error Error message, if any.
   * @param {module:model/Message} data The data returned by the service call.
   * @param {String} response The complete HTTP response.
   */

  /**
   * Create Assignment
   * Create a assignments for a semester with given userID, semesterID
   * @param {String} uid 
   * @param {String} lid 
   * @param {module:model/AssignmentModel} assignmentModel 
   * @param {module:api/AssignmentsApi~createAssignmentCallback} callback The callback function, accepting three arguments: error, data, response
   * data is of type: {@link module:model/Message}
   */


  _createClass(AssignmentsApi, [{
    key: "createAssignment",
    value: function createAssignment(uid, lid, assignmentModel, callback) {
      var postBody = assignmentModel; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling createAssignment");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling createAssignment");
      } // verify the required parameter 'assignmentModel' is set


      if (assignmentModel === undefined || assignmentModel === null) {
        throw new Error("Missing the required parameter 'assignmentModel' when calling createAssignment");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/assignments', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the deleteAssignment operation.
     * @callback module:api/AssignmentsApi~deleteAssignmentCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Message} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Delete Assignment
     * Delete an assignment with given userID, lectureID and assignmentID
     * @param {String} uid 
     * @param {String} lid 
     * @param {String} aid 
     * @param {module:api/AssignmentsApi~deleteAssignmentCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Message}
     */

  }, {
    key: "deleteAssignment",
    value: function deleteAssignment(uid, lid, aid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling deleteAssignment");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling deleteAssignment");
      } // verify the required parameter 'aid' is set


      if (aid === undefined || aid === null) {
        throw new Error("Missing the required parameter 'aid' when calling deleteAssignment");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'aid': aid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/assignments/{aid}', 'DELETE', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the getSingleAssignment operation.
     * @callback module:api/AssignmentsApi~getSingleAssignmentCallback
     * @param {String} error Error message, if any.
     * @param {module:model/AssignmentModel} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Show Assignment
     * Get a single assignment with given userID, lectureID and assignmentID
     * @param {String} uid 
     * @param {String} lid 
     * @param {String} aid 
     * @param {module:api/AssignmentsApi~getSingleAssignmentCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/AssignmentModel}
     */

  }, {
    key: "getSingleAssignment",
    value: function getSingleAssignment(uid, lid, aid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling getSingleAssignment");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling getSingleAssignment");
      } // verify the required parameter 'aid' is set


      if (aid === undefined || aid === null) {
        throw new Error("Missing the required parameter 'aid' when calling getSingleAssignment");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'aid': aid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _AssignmentModel["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/lessons/{aid}', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the listAssignmentsOfLecture operation.
     * @callback module:api/AssignmentsApi~listAssignmentsOfLectureCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:model/AssignmentModel>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * List Assignments
     * List all assignments of a lecture with given userID, lectureID
     * @param {String} uid 
     * @param {String} lid 
     * @param {module:api/AssignmentsApi~listAssignmentsOfLectureCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:model/AssignmentModel>}
     */

  }, {
    key: "listAssignmentsOfLecture",
    value: function listAssignmentsOfLecture(uid, lid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling listAssignmentsOfLecture");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling listAssignmentsOfLecture");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = [_AssignmentModel["default"]];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/assignments', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the updateAssignment operation.
     * @callback module:api/AssignmentsApi~updateAssignmentCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Message} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Update Assignment
     * Update an assignment with given userID, lectureID and assignmentID
     * @param {String} uid 
     * @param {String} lid 
     * @param {String} aid 
     * @param {module:model/AssignmentModel} assignmentModel 
     * @param {module:api/AssignmentsApi~updateAssignmentCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Message}
     */

  }, {
    key: "updateAssignment",
    value: function updateAssignment(uid, lid, aid, assignmentModel, callback) {
      var postBody = assignmentModel; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling updateAssignment");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling updateAssignment");
      } // verify the required parameter 'aid' is set


      if (aid === undefined || aid === null) {
        throw new Error("Missing the required parameter 'aid' when calling updateAssignment");
      } // verify the required parameter 'assignmentModel' is set


      if (assignmentModel === undefined || assignmentModel === null) {
        throw new Error("Missing the required parameter 'assignmentModel' when calling updateAssignment");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'aid': aid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/assignments/{aid}', 'PUT', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
  }]);

  return AssignmentsApi;
}();

exports["default"] = AssignmentsApi;