"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _HTTPValidationError = _interopRequireDefault(require("../model/HTTPValidationError"));

var _Message = _interopRequireDefault(require("../model/Message"));

var _StudentGradeModel = _interopRequireDefault(require("../model/StudentGradeModel"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
* Grades service.
* @module api/GradesApi
* @version 0.1.0
*/
var GradesApi = /*#__PURE__*/function () {
  /**
  * Constructs a new GradesApi. 
  * @alias module:api/GradesApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function GradesApi(apiClient) {
    _classCallCheck(this, GradesApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Callback function to receive the result of the createGrade operation.
   * @callback module:api/GradesApi~createGradeCallback
   * @param {String} error Error message, if any.
   * @param {module:model/Message} data The data returned by the service call.
   * @param {String} response The complete HTTP response.
   */

  /**
   * Create Grade
   * Create a grades for a semester with given userID, semesterID
   * @param {String} uid 
   * @param {String} lid 
   * @param {String} sid 
   * @param {module:model/StudentGradeModel} studentGradeModel 
   * @param {module:api/GradesApi~createGradeCallback} callback The callback function, accepting three arguments: error, data, response
   * data is of type: {@link module:model/Message}
   */


  _createClass(GradesApi, [{
    key: "createGrade",
    value: function createGrade(uid, lid, sid, studentGradeModel, callback) {
      var postBody = studentGradeModel; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling createGrade");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling createGrade");
      } // verify the required parameter 'sid' is set


      if (sid === undefined || sid === null) {
        throw new Error("Missing the required parameter 'sid' when calling createGrade");
      } // verify the required parameter 'studentGradeModel' is set


      if (studentGradeModel === undefined || studentGradeModel === null) {
        throw new Error("Missing the required parameter 'studentGradeModel' when calling createGrade");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'sid': sid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/students/{sid}', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the deleteGrade operation.
     * @callback module:api/GradesApi~deleteGradeCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Message} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Delete Grade
     * Delete an student with given userID, lectureID and studentID
     * @param {String} uid 
     * @param {String} lid 
     * @param {String} sid 
     * @param {String} gid 
     * @param {module:api/GradesApi~deleteGradeCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Message}
     */

  }, {
    key: "deleteGrade",
    value: function deleteGrade(uid, lid, sid, gid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling deleteGrade");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling deleteGrade");
      } // verify the required parameter 'sid' is set


      if (sid === undefined || sid === null) {
        throw new Error("Missing the required parameter 'sid' when calling deleteGrade");
      } // verify the required parameter 'gid' is set


      if (gid === undefined || gid === null) {
        throw new Error("Missing the required parameter 'gid' when calling deleteGrade");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'sid': sid,
        'gid': gid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/students/{sid}/grades/{gid}', 'DELETE', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the getSingleGrade operation.
     * @callback module:api/GradesApi~getSingleGradeCallback
     * @param {String} error Error message, if any.
     * @param {module:model/StudentGradeModel} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Show Grade
     * Get a single assignment with given userID, lectureID and assignmentID
     * @param {String} uid 
     * @param {String} lid 
     * @param {String} aid 
     * @param {String} sid 
     * @param {module:api/GradesApi~getSingleGradeCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/StudentGradeModel}
     */

  }, {
    key: "getSingleGrade",
    value: function getSingleGrade(uid, lid, aid, sid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling getSingleGrade");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling getSingleGrade");
      } // verify the required parameter 'aid' is set


      if (aid === undefined || aid === null) {
        throw new Error("Missing the required parameter 'aid' when calling getSingleGrade");
      } // verify the required parameter 'sid' is set


      if (sid === undefined || sid === null) {
        throw new Error("Missing the required parameter 'sid' when calling getSingleGrade");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'aid': aid,
        'sid': sid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _StudentGradeModel["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/students/{sid}/grades/{aid}', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the listGradesOfStudent operation.
     * @callback module:api/GradesApi~listGradesOfStudentCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:model/StudentGradeModel>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * List Grades
     * List all gradess of a student with given userID, lectureID
     * @param {String} uid 
     * @param {String} lid 
     * @param {String} sid 
     * @param {module:api/GradesApi~listGradesOfStudentCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:model/StudentGradeModel>}
     */

  }, {
    key: "listGradesOfStudent",
    value: function listGradesOfStudent(uid, lid, sid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling listGradesOfStudent");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling listGradesOfStudent");
      } // verify the required parameter 'sid' is set


      if (sid === undefined || sid === null) {
        throw new Error("Missing the required parameter 'sid' when calling listGradesOfStudent");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'sid': sid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = [_StudentGradeModel["default"]];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/students/{sid}/grades', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the updateGrade operation.
     * @callback module:api/GradesApi~updateGradeCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Message} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Update Grade
     * Update an grade with given userID, lectureID and gradeID
     * @param {String} uid 
     * @param {String} lid 
     * @param {String} sid 
     * @param {String} gid 
     * @param {module:model/StudentGradeModel} studentGradeModel 
     * @param {module:api/GradesApi~updateGradeCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Message}
     */

  }, {
    key: "updateGrade",
    value: function updateGrade(uid, lid, sid, gid, studentGradeModel, callback) {
      var postBody = studentGradeModel; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling updateGrade");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling updateGrade");
      } // verify the required parameter 'sid' is set


      if (sid === undefined || sid === null) {
        throw new Error("Missing the required parameter 'sid' when calling updateGrade");
      } // verify the required parameter 'gid' is set


      if (gid === undefined || gid === null) {
        throw new Error("Missing the required parameter 'gid' when calling updateGrade");
      } // verify the required parameter 'studentGradeModel' is set


      if (studentGradeModel === undefined || studentGradeModel === null) {
        throw new Error("Missing the required parameter 'studentGradeModel' when calling updateGrade");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'sid': sid,
        'gid': gid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/students/{sid}/grades/{gid}', 'PUT', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
  }]);

  return GradesApi;
}();

exports["default"] = GradesApi;