"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _HTTPValidationError = _interopRequireDefault(require("../model/HTTPValidationError"));

var _LectureModel = _interopRequireDefault(require("../model/LectureModel"));

var _Message = _interopRequireDefault(require("../model/Message"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
* Lectures service.
* @module api/LecturesApi
* @version 0.1.0
*/
var LecturesApi = /*#__PURE__*/function () {
  /**
  * Constructs a new LecturesApi. 
  * @alias module:api/LecturesApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function LecturesApi(apiClient) {
    _classCallCheck(this, LecturesApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Callback function to receive the result of the createLecture operation.
   * @callback module:api/LecturesApi~createLectureCallback
   * @param {String} error Error message, if any.
   * @param {module:model/Message} data The data returned by the service call.
   * @param {String} response The complete HTTP response.
   */

  /**
   * Create Lecture
   * Create a lecture for a user with given userID
   * @param {String} uid 
   * @param {module:model/LectureModel} lectureModel 
   * @param {module:api/LecturesApi~createLectureCallback} callback The callback function, accepting three arguments: error, data, response
   * data is of type: {@link module:model/Message}
   */


  _createClass(LecturesApi, [{
    key: "createLecture",
    value: function createLecture(uid, lectureModel, callback) {
      var postBody = lectureModel; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling createLecture");
      } // verify the required parameter 'lectureModel' is set


      if (lectureModel === undefined || lectureModel === null) {
        throw new Error("Missing the required parameter 'lectureModel' when calling createLecture");
      }

      var pathParams = {
        'uid': uid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the deleteLecture operation.
     * @callback module:api/LecturesApi~deleteLectureCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Message} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Delete Lecture
     * Delete a lecture with given userID and lectureID
     * @param {String} uid 
     * @param {String} lid 
     * @param {module:api/LecturesApi~deleteLectureCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Message}
     */

  }, {
    key: "deleteLecture",
    value: function deleteLecture(uid, lid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling deleteLecture");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling deleteLecture");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}', 'DELETE', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the getSingleLecture operation.
     * @callback module:api/LecturesApi~getSingleLectureCallback
     * @param {String} error Error message, if any.
     * @param {module:model/LectureModel} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Show Lecture
     * Get a single lecture with given userID and lectureID
     * @param {String} uid 
     * @param {String} lid 
     * @param {module:api/LecturesApi~getSingleLectureCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/LectureModel}
     */

  }, {
    key: "getSingleLecture",
    value: function getSingleLecture(uid, lid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling getSingleLecture");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling getSingleLecture");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _LectureModel["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the listLectures operation.
     * @callback module:api/LecturesApi~listLecturesCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:model/LectureModel>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * List Lectures
     * list all lectures
     * @param {String} uid 
     * @param {module:api/LecturesApi~listLecturesCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:model/LectureModel>}
     */

  }, {
    key: "listLectures",
    value: function listLectures(uid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling listLectures");
      }

      var pathParams = {
        'uid': uid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = [_LectureModel["default"]];
      return this.apiClient.callApi('/users/{uid}/lectures', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the updateLecture operation.
     * @callback module:api/LecturesApi~updateLectureCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Message} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Update Lecture
     * Update a lecture with given userID and lectureID
     * @param {String} uid 
     * @param {String} lid 
     * @param {module:model/LectureModel} lectureModel 
     * @param {module:api/LecturesApi~updateLectureCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Message}
     */

  }, {
    key: "updateLecture",
    value: function updateLecture(uid, lid, lectureModel, callback) {
      var postBody = lectureModel; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling updateLecture");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling updateLecture");
      } // verify the required parameter 'lectureModel' is set


      if (lectureModel === undefined || lectureModel === null) {
        throw new Error("Missing the required parameter 'lectureModel' when calling updateLecture");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}', 'PUT', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
  }]);

  return LecturesApi;
}();

exports["default"] = LecturesApi;