"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _HTTPValidationError = _interopRequireDefault(require("../model/HTTPValidationError"));

var _Message = _interopRequireDefault(require("../model/Message"));

var _StudentModel = _interopRequireDefault(require("../model/StudentModel"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
* Students service.
* @module api/StudentsApi
* @version 0.1.0
*/
var StudentsApi = /*#__PURE__*/function () {
  /**
  * Constructs a new StudentsApi. 
  * @alias module:api/StudentsApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function StudentsApi(apiClient) {
    _classCallCheck(this, StudentsApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Callback function to receive the result of the createStudent operation.
   * @callback module:api/StudentsApi~createStudentCallback
   * @param {String} error Error message, if any.
   * @param {module:model/Message} data The data returned by the service call.
   * @param {String} response The complete HTTP response.
   */

  /**
   * Create Student
   * Create a students for a semester with given userID, semesterID
   * @param {String} uid 
   * @param {String} lid 
   * @param {module:model/StudentModel} studentModel 
   * @param {module:api/StudentsApi~createStudentCallback} callback The callback function, accepting three arguments: error, data, response
   * data is of type: {@link module:model/Message}
   */


  _createClass(StudentsApi, [{
    key: "createStudent",
    value: function createStudent(uid, lid, studentModel, callback) {
      var postBody = studentModel; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling createStudent");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling createStudent");
      } // verify the required parameter 'studentModel' is set


      if (studentModel === undefined || studentModel === null) {
        throw new Error("Missing the required parameter 'studentModel' when calling createStudent");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/students', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the deleteStudent operation.
     * @callback module:api/StudentsApi~deleteStudentCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Message} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Delete Student
     * Delete an student with given userID, lectureID and studentID
     * @param {String} uid 
     * @param {String} lid 
     * @param {String} sid 
     * @param {module:api/StudentsApi~deleteStudentCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Message}
     */

  }, {
    key: "deleteStudent",
    value: function deleteStudent(uid, lid, sid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling deleteStudent");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling deleteStudent");
      } // verify the required parameter 'sid' is set


      if (sid === undefined || sid === null) {
        throw new Error("Missing the required parameter 'sid' when calling deleteStudent");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'sid': sid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/students/{sid}', 'DELETE', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the getSingleStudent operation.
     * @callback module:api/StudentsApi~getSingleStudentCallback
     * @param {String} error Error message, if any.
     * @param {module:model/StudentModel} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Show Student
     * Get a single assignment with given userID, lectureID and assignmentID
     * @param {String} uid 
     * @param {String} lid 
     * @param {String} sid 
     * @param {module:api/StudentsApi~getSingleStudentCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/StudentModel}
     */

  }, {
    key: "getSingleStudent",
    value: function getSingleStudent(uid, lid, sid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling getSingleStudent");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling getSingleStudent");
      } // verify the required parameter 'sid' is set


      if (sid === undefined || sid === null) {
        throw new Error("Missing the required parameter 'sid' when calling getSingleStudent");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'sid': sid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _StudentModel["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/students/{sid}', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the listStudentsOfLecture operation.
     * @callback module:api/StudentsApi~listStudentsOfLectureCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:model/StudentModel>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * List Students
     * List all students of a lecture with given userID, lectureID
     * @param {String} uid 
     * @param {String} lid 
     * @param {module:api/StudentsApi~listStudentsOfLectureCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:model/StudentModel>}
     */

  }, {
    key: "listStudentsOfLecture",
    value: function listStudentsOfLecture(uid, lid, callback) {
      var postBody = null; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling listStudentsOfLecture");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling listStudentsOfLecture");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = [_StudentModel["default"]];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/students', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the updateStudent operation.
     * @callback module:api/StudentsApi~updateStudentCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Message} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Update Student
     * Update an student with given userID, lectureID and studentID
     * @param {String} uid 
     * @param {String} lid 
     * @param {String} sid 
     * @param {module:model/StudentModel} studentModel 
     * @param {module:api/StudentsApi~updateStudentCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Message}
     */

  }, {
    key: "updateStudent",
    value: function updateStudent(uid, lid, sid, studentModel, callback) {
      var postBody = studentModel; // verify the required parameter 'uid' is set

      if (uid === undefined || uid === null) {
        throw new Error("Missing the required parameter 'uid' when calling updateStudent");
      } // verify the required parameter 'lid' is set


      if (lid === undefined || lid === null) {
        throw new Error("Missing the required parameter 'lid' when calling updateStudent");
      } // verify the required parameter 'sid' is set


      if (sid === undefined || sid === null) {
        throw new Error("Missing the required parameter 'sid' when calling updateStudent");
      } // verify the required parameter 'studentModel' is set


      if (studentModel === undefined || studentModel === null) {
        throw new Error("Missing the required parameter 'studentModel' when calling updateStudent");
      }

      var pathParams = {
        'uid': uid,
        'lid': lid,
        'sid': sid
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['OAuth2PasswordBearer'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _Message["default"];
      return this.apiClient.callApi('/users/{uid}/lectures/{lid}/students/{sid}', 'PUT', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
  }]);

  return StudentsApi;
}();

exports["default"] = StudentsApi;